@@ -2019,6 +2019,10 @@ class Pow(Expr):
             return Conjugate(b) ** e
         return Conjugate(self)
 
+    def _eval_torch(self):
+        b, e = self.args
+        return b.torch ** e.torch
+    
     
 from .add import Add
 from .numbers import Integer
