@@ -623,6 +623,11 @@ class Symbol(AtomicExpr, NotIterable):
         if 'definition' in self._assumptions:
             return self._assumptions['definition']
 
+    @property
+    def var(self):
+        from sympy.stats.rv import pspace
+        return pspace(self).symbol
+
     @cacheit
     def defun(self):
         if 'definition' in self._assumptions:
@@ -960,28 +965,20 @@ class Symbol(AtomicExpr, NotIterable):
             if len(self.shape) < 2:
                 return self
 
-    @staticmethod
-    def ascii2greek(x):
-        if x.lower() in {'alpha', 'beta', 'gamma', 'delta', 'epsilon', 'zeta', 'eta', 'theta', 'iota', 'kappa', 'lamda', 'mu', 'nu', 'xi', 'omicron', 'pi', 'rho', 'sigma', 'tau', 'upsilon', 'phi', 'chi', 'psi', 'omega'}:
-            if x[0].isupper():
-                x = eval("'\\N{GREEK CAPITAL LETTER %s}'" % x)
-            else:
-                x = eval("'\\N{GREEK SMALL LETTER %s}'" % x)
-        return x
-        
     @staticmethod
     def sympystr(name):
         m = _re.compile("([a-zA-Z]+)(?:(\d+)|_(\w+))?").fullmatch(name)
         if m: 
+            from std.unicode import ascii2greek
             x = m[1]
-            x = Symbol.ascii2greek(x)
+            x = ascii2greek(x)
             d = m[2]
             if d is not None:
                 x += d
             else:
                 a = m[3]
                 if a is not None:
-                    a = Symbol.ascii2greek(a)
+                    a = ascii2greek(a)
                     x += '_' + a                    
                 
             return x
@@ -1403,6 +1400,16 @@ class Symbol(AtomicExpr, NotIterable):
         
         return definition.torch
 
+    @cacheit
+    def compile(self, *syms):
+        assert all(self._has(v) for v in syms)
+        definition = self.definition
+        if definition is None:
+            from sympy.keras.network import NetWorkSymbol
+            return NetWorkSymbol(self)
+        
+        return definition.compile(*syms)
+
     def find_path(self, cls, path, **kwargs):
         for attr in kwargs:
             value = getattr(self, attr)
@@ -1410,19 +1417,8 @@ class Symbol(AtomicExpr, NotIterable):
                 path.append(attr)
                 yield from value.find_path(cls, path, **kwargs)
                 path.pop()
+                
             
-    def _assumptions_clear_cache(self, cacheType, sym):
-        if self._has(sym):
-            try:
-                self.__delattr__(cacheType)
-            except AttributeError:
-                ...
-            
-            definition = self.definition
-            if definition is not None:
-                definition._assumptions_clear_cache(cacheType, sym)
-            
-    
 class Dummy(Symbol):
     """Dummy symbols are each unique, even if they have the same name:
 
