@@ -459,7 +459,18 @@ class Exp(ExpBase):
         if arg is None:
             return None, 0
         return self.func(arg, evaluate=False), monotonicity
+
+    def _eval_torch(self):
+        return self.arg.torch.exp()
     
+    @staticmethod
+    def simplify_Lamda(self, squeeze=False):
+        simplified = self.func(self.expr.arg, *self.limits).simplify()
+        if not simplified.is_Lamda:
+            return Exp(simplified)
+
+        return self
+            
 exp = Exp
     
 def match_real_imag(expr):
