@@ -26,17 +26,20 @@ class Module:
             module.make_substitutions()            
     
     def load_weights(self, h5):
+        state_dict = {}
         import numpy as np
         for name, weight in self._weights.items():
             try:
-                weight.numpy = np.array(h5[name])
+                state_dict[weight] = np.array(h5[name])
             except KeyError:
                 print(weight, "is not initialized properly")
-                weight.numpy = np.random.rand(*weight.shape)
+                state_dict[weight] = np.random.rand(*weight.shape)
                 
         for name, module in self._modules.items():
-            module.load_weights(h5[name])
-
+            state_dict |= module.load_weights(h5[name])
+            
+        return state_dict
+    
     def _hook_for_profile(self):
         def profile_hook_forward(func):
 
