@@ -690,7 +690,7 @@ class BlockMatrix(MatrixExpr):
 
     def _subs(self, old, new, **hints):
         if old.is_BlockMatrix and self.axis == old.axis:
-            from sympy.utilities.misc import sunday
+            from std.search import sunday
             i = sunday(self.args, old.args)
             if i >= 0:
                 args = self.args[:i]
@@ -742,7 +742,12 @@ class BlockMatrix(MatrixExpr):
     def _hashable_content(self):
         return self._args + (self.axis,)
     
-        
+    
+    @staticmethod
+    def simplify_Lamda(self, squeeze=False):
+        return self
+    
+    
 class BlockDiagMatrix(MatrixExpr):
     """
     A BlockDiagMatrix is a BlockMatrix with matrices only along the diagonal
