@@ -483,12 +483,16 @@ class LatexPrinter(Printer):
         '''
         func = self._deal_with_super_sub(func)
         if func in accepted_latex_functions:
-            name = r"\%s" % func
-        elif len(func) == 1 or func.startswith('\\'):
-            name = func
+            func = r"\%s" % func
+        elif len(func) == 1:
+            from std.unicode import ascii2greek
+            if func == ascii2greek('phi'):
+                func = '\\phi'
+        elif func.startswith('\\'):
+            ...
         else:
-            name = r"\operatorname{%s}" % func
-        return name
+            func = r"\operatorname{%s}" % func
+        return func
 
     def _print_UndefinedFunction(self, expr):
         return self._hprint_Function(str(expr))
