@@ -261,7 +261,12 @@ class Probability(Expr):
     
     def __new__(cls, *prob, given=None, evaluate=False): 
         booleans = []
+        limits = ()
         for arg in prob:
+            if isinstance(arg, tuple):
+                limits = arg
+                continue
+
             assert arg.is_random
             if arg.is_symbol:
                 booleans.append(Equal(arg, pspace(arg).symbol))
@@ -277,8 +282,8 @@ class Probability(Expr):
         expr = And(*booleans)
         if given is not None:
             expr = rv.given(expr, given)
-        obj = Expr.__new__(cls, expr)
-        return obj            
+        obj = Expr.__new__(cls, expr, *limits)
+        return obj
 
     def doit(self, **hints):
         condition = self.args[0]
@@ -335,9 +340,20 @@ class Probability(Expr):
     def evaluate_integral(self):
         return self.rewrite(Integral).doit()
 
-    def _latex(self, p):        
-        return r'\mathbb{P}%s' % p._print(self.args)
-    
+    def _latex(self, p):
+        expr, *limits = self.args
+        if limits:
+            return r'\mathbb{P}_{%s}%s' % (','.join([p._print(s) for s in limits]), p._print(self.args[:1]))
+        else:
+            return r'\mathbb{P}%s' % p._print(self.args)
+
+    def _sympystr(self, p):
+        expr, *limits = self.args
+        if limits:
+            return 'P[%s](%s)' % (','.join([p._print(s) for s in limits]), p._print(expr))
+        else:
+            return 'P(%s)' % p._print(self.args)
+
     def domain_definition(self):        
         return self.arg.domain_definition()
     
